import {reactive, toRefs} from '@vue/reactivity'
import {DataRectangle} from "@/types";
import {readonly} from "vue";

/**
 * Define our state
 *
 * This state is mutable in the function below, but if we pass it to the component without `toRefs` it will not mutate.
 */
const state = reactive({
    markerModel: [[]] as DataRectangle[][],
    isDrawing: false,
})

export default () => {
    const resetModelPage = (pageNumber: number) => state.markerModel[pageNumber - 1] = []

    const addToModel = (pageNumber: number, ...items: DataRectangle[]) => {
        console.trace('addToModel', pageNumber, items)
        if (state.markerModel.length < pageNumber) {
            state.markerModel.push([])
        }

        items = items.reverse().filter((drawRectangle, index, self) =>
            index === self.findIndex(rect => rect.uid === drawRectangle.uid)
        ).reverse()

        console.log('added', items)

        state.markerModel[pageNumber - 1].push(...items)
    }

    const setIsDrawing = (isDrawing: boolean) => state.isDrawing = isDrawing

    /**
     * Return the state as a `reference` to make it mutable.
     */
    return readonly({
        state,
        addToModel,
        resetModelPage,
        setIsDrawing,
    })
}
